"""
topical-matcher - UDC/IAB document classification toolkit.

This package is under development. Full release coming soon.
"""

__version__ = "0.0.1"
__author__ = "Turov Team"


class TopicalMatcher:
    """Placeholder for TopicalMatcher class."""

    def __init__(self, *args, **kwargs):
        raise NotImplementedError(
            "topical-matcher is under development. "
            "Full release coming soon. "
            "Contact maintainers for early access."
        )


def classify(*args, **kwargs):
    """Placeholder for classify function."""
    raise NotImplementedError(
        "topical-matcher is under development. "
        "Full release coming soon."
    )
